@@ -4,6 +4,7 @@ MODE = "Mode"
 XRAY = "XRay"
 LAYERS = "Layers"
 HTTP_API = "HttpApi"
+REST_API = "RestApi"
 IOT = "IoT"
 CODE_DEPLOY = "CodeDeploy"
 ARM = "ARM"
@@ -21,3 +22,4 @@ SNS = "SNS"
 SQS = "SQS"
 CUSTOM_DOMAIN = "CustomDomain"
 ARM = "ARM"
+EFS = "EFS"
