@@ -11,7 +11,7 @@ class TestFunctionWithHttpApiAndAuth(BaseTest):
         # We are not testing that IAM auth works here, we are simply testing if it was applied.
         IAM_AUTH_OUTPUT = '{"message":"Forbidden"}'
 
-        self.create_and_verify_stack("function_with_http_api_events_and_auth")
+        self.create_and_verify_stack("single/function_with_http_api_events_and_auth")
 
         implicitEndpoint = self.get_api_v2_endpoint("ServerlessHttpApi")
         self.assertEqual(
